.. _howto-craft_cli_upload_progress:

Using craft-cli for upload progress
===================================

Progress can be provided by use of craft-cli_. This example will upload
``./test.snap`` with something that looks like the following:

The example requires setting the environment variable
``SNAPCRAFT_STORE_CREDENTIALS`` using a file generated by
`snapcraft export-login`_.

.. literalinclude:: code/craft-cli-upload-progress/craft_cli_upload.py
    :language: python

.. _craft-cli: https://canonical-craft-cli.readthedocs-hosted.com/en/latest/
.. _snapcraft export-login: https://snapcraft.io/docs/snapcraft-authentication
